<?php
/**
 * Catch Flames Theme Options
 *
 * @package Catch Themes
 * @subpackage Catch Flames
 * @since Catch Flames 1.0
 */
add_action( 'admin_init', 'catchflames_register_settings' );
add_action( 'admin_menu', 'catchflames_options_menu' );


/**
 * Enqueue admin script and styles
 *
 * @uses wp_register_script, wp_enqueue_script and wp_enqueue_style
 * @Calling jquery, jquery-ui-tabs,jquery-cookie, jquery-ui-sortable, jquery-ui-draggable, media-upload, thickbox, farbtastic, colorpicker
 */
function catchflames_admin_scripts() {
	//jquery-cookie registered in functions.php
	wp_enqueue_script( 'catchflames_admin', esc_url( get_template_directory_uri() ).'/inc/panel/admin.min.js', array( 'jquery', 'jquery-ui-tabs', 'jquery-cookie', 'jquery-ui-sortable', 'jquery-ui-draggable' ) );

    wp_enqueue_media();

    wp_enqueue_script( 'catchflames_upload', esc_url( get_template_directory_uri() ).'/inc/panel/add_image_scripts.min.js', array( 'jquery' ) );

	wp_enqueue_style( 'catchflames_admin',esc_url( get_template_directory_uri() ).'/inc/panel/admin.css', '', '1.0', 'screen' );
}
add_action( 'admin_print_styles-appearance_page_theme_options', 'catchflames_admin_scripts' );


/**
 * Enqueue admin script and styles
 *
 * @uses wp_register_script, wp_enqueue_script and wp_enqueue_style
 * @Calling jquery, jquery-ui-tabs,jquery-cookie, jquery-ui-sortable, jquery-ui-draggable, media-upload, thickbox, farbtastic, colorpicker
 */
function catchflames_admin_style() {
	wp_enqueue_style( 'catchflames_admin_page_post',esc_url( get_template_directory_uri() ).'/inc/panel/admin-page-post.css', '1.0', 'screen' );
}
add_action( 'admin_print_styles', 'catchflames_admin_style' );


/*
 * Create a function for Theme Options Page
 *
 * @uses add_theme_page
 * @add action admin_menu
 */
function catchflames_options_menu() {

	add_theme_page(
        __( 'Theme Options', 'catch-flames' ),           // Name of page
        __( 'Theme Options', 'catch-flames' ),           // Label in menu
        'edit_theme_options',                           // Capability required
        'theme_options',                                // Menu slug, used to uniquely identify the page
        'catchflames_theme_options_do_page'             // Function that renders the options page
    );

}


/*
 * Register options and validation callbacks
 *
 * @uses register_setting
 * @action admin_init
 */
function catchflames_register_settings(){
	register_setting( 'catchflames_options', 'catchflames_options', 'catchflames_theme_options_validate' );
}


/*
 * Render Catch Flames Theme Options page
 *
 * @uses settings_fields, get_option, bloginfo
 * @Settings Updated
 */
function catchflames_theme_options_do_page() {
	if (!isset($_REQUEST['settings-updated']))
		$_REQUEST['settings-updated'] = false;
	?>

	<div id="catchthemes" class="wrap">

    	<form method="post" action="options.php">
			<?php
                settings_fields( 'catchflames_options' );
                global $catchflames_options_settings;
                $options = $catchflames_options_settings;

				//Getting Units
				$units = array( 'px', 'pt', 'em', '%' );
            ?>

            <?php if (false !== $_REQUEST['settings-updated']) : ?>
            	<div class="updated fade"><p><strong><?php _e('Options Saved', 'catch-flames'); ?></strong></p></div>
            <?php endif; ?>

			<div id="theme-option-header">
                <div id="theme-option-title">
                    <h2 class="title"><?php _e( 'Theme Options By', 'catch-flames' ); ?></h2>
                    <h2 class="logo">
                        <a href="<?php echo esc_url( __( 'https://catchthemes.com/', 'catch-flames' ) ); ?>" title="<?php esc_attr_e( 'Catch Themes', 'catch-flames' ); ?>" target="_blank">
                            <img src="<?php echo esc_url( get_template_directory_uri() ).'/inc/panel/images/catch-themes.png'; ?>" alt="<?php _e( 'Catch Themes', 'catch-flames' ); ?>" />
                        </a>
                    </h2>
                </div><!-- #theme-option-title -->

                <div id="theme-support">
                    <ul>
                        <li><a class="button" href="<?php echo esc_url( __( 'https://catchthemes.com/support-forum/forum/catch-flames-pro-premium/','catch-flames' ) ); ?>" title="<?php esc_attr_e( 'Support Forum', 'catch-flames' ); ?>" target="_blank"><?php printf( __( 'Support Forum','catch-flames' ) ); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url( __( 'https://catchthemes.com/theme-instructions/catch-flames-pro/','catch-flames' ) ); ?>" title="<?php esc_attr_e( 'Theme Instruction', 'catch-flames' ); ?>" target="_blank"><?php printf( __( 'Theme Instruction','catch-flames' ) ); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url( __( 'https://www.facebook.com/catchthemes/','catch-flames' ) ); ?>" title="<?php esc_attr_e( 'Like Catch Themes on Facebook', 'catch-flames' ); ?>" target="_blank"><?php printf( __( 'Facebook','catch-flames' ) ); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url( __( 'https://twitter.com/catchthemes/','catch-flames' ) ); ?>" title="<?php esc_attr_e( 'Follow Catch Themes on Twitter', 'catch-flames' ); ?>" target="_blank"><?php printf( __( 'Twitter','catch-flames' ) ); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url( __( 'https://plus.google.com/+Catchthemes','catch-flames' ) ); ?>" title="<?php esc_attr_e( 'Follow Catch Themes on Google+', 'catch-flames' ); ?>" target="_blank"><?php printf( __( 'Google+','catch-flames' ) ); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url( __( 'http://wordpress.org/support/view/theme-reviews/catch-flames/','catch-flames' ) ); ?>" title="<?php esc_attr_e( 'Rate us 5 Star on WordPress', 'catch-flames' ); ?>" target="_blank"><?php printf( __( '5 Star Rating','catch-flames' ) ); ?></a></li>
                   	</ul>
                </div><!-- #theme-support -->
          	</div><!-- #theme-option-header -->

            <div id="theme-option-header-notice">
                <p class="notice">
                    <?php printf( _x( 'Theme Options Panel will be retired on future versions. Please use %1$s Customizer %2$s instead.','1: Customizer Link Start, 2: Customizer Link End' , 'catch-flames' ) , '<a href="' . esc_url ( admin_url( 'customize.php' ) ) . '">', '</a>' ); ?>
                </p>
            </div>


            <div id="catchflames_ad_tabs">
                <ul class="tabNavigation" id="mainNav">
                    <li><a href="#themeoptions"><?php _e( 'Theme Options', 'catch-flames' );?></a></li>
                    <li><a href="#color-options"><?php _e( 'Color Options', 'catch-flames' );?></a></li>
                    <li><a href="#contentsettings"><?php _e( 'Featured Content', 'catch-flames' );?></a></li>
                    <li><a href="#slidersettings"><?php _e( 'Featured Slider', 'catch-flames' );?></a></li>
                    <li><a href="#sociallinks"><?php _e( 'Social Links', 'catch-flames' );?></a></li>
                </ul><!-- .tabsNavigation #mainNav -->

                <!-- Option for Theme Options -->
                <div id="themeoptions">
                    <div id="fixed-header-top-options" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Fixed Header Top Options', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                      		<div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Enable Fixed Header Top?', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type='hidden' value='0' name='catchflames_options[enable_header_top]'>
                                  	<input type="checkbox" id="enable-header-top" name="catchflames_options[enable_header_top]" value="1" <?php checked( '1', $options['enable_header_top'] ); ?> /> <?php _e('Check to enable', 'catch-flames'); ?>
                           		</div>
                         	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Disable Logo in Fixed Header Top?', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type='hidden' value='0' name='catchflames_options[disable_top_menu_logo]'>
                                   	<input type="checkbox" id="disable-fixed-logo" name="catchflames_options[disable_top_menu_logo]" value="1" <?php checked( '1', $options['disable_top_menu_logo'] ); ?> /> <?php _e('Check to disable', 'catch-flames'); ?>
                           		</div>
                         	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Logo in Fixed Header Top:', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
									<?php  if ( !empty ( $options['top_menu_logo'] ) ) { ?>
                                    	<input  class="upload-url" size="65" type="text" name="catchflames_options[top_menu_logo]" value="<?php echo esc_url ( $options['top_menu_logo']); ?>" class="upload" />
                                    <?php } else { ?>
                                     	<input class="upload-url" size="65" type="text" name="catchflames_options[top_menu_logo]" value="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>images/fixed-logo.png" alt="logo" />
                                    <?php }  ?>
                                  	<input ref="<?php esc_attr_e( 'Insert as Header Logo','catch-flames' );?>" class="catchflames_upload_image button" name="wsl-image-add" type="button" value="<?php esc_attr_e( 'Change Header Logo','catch-flames' );?>" />
                           		</div>
                         	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Fixed Header Top Menu', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	 <?php _e( 'You need to create custom menu and then assign menu location as Featured Header Top Menu. For more go to Menu Option Below', 'catch-flames' ); ?>
                           		</div>
                         	</div><!-- .row -->
                            <div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

       				<div id="header-options" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Header Options', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Custom Header Image', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<?php _e( 'Custom Header Image can be managed from Header Featured Image Options', 'catch-flames' ); ?>
                           		</div>
                         	</div><!-- .row -->
                            <?php
                            //@remove Remove if block when WordPress 4.8 is released
                            if( !function_exists( 'has_custom_logo' ) ) {
                            ?>
                                <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Disable Header Logo?', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type='hidden' value='0' name='catchflames_options[remove_header_logo]'>
                                   	<input type="checkbox" id="headerlogo" name="catchflames_options[remove_header_logo]" value="1" <?php checked( '1', $options['remove_header_logo'] ); ?> /> <?php _e('Check to disable', 'catch-flames'); ?>
                           		</div>
                             	</div><!-- .row -->
                                <div class="row">
                                	<div class="col col-1">
                                    	<?php _e( 'Logo url:', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-2">
    									<?php  if ( !empty ( $options['featured_logo_header'] ) ) { ?>
                                        	<input  class="upload-url" size="65" type="text" name="catchflames_options[featured_logo_header]" value="<?php echo esc_url ( $options['featured_logo_header']); ?>" class="upload" />
                                         <?php } else { ?>
                                         	<input class="upload-url" size="65" type="text" name="catchflames_options[featured_logo_header]" value="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>images/logo.png" alt="logo" />
                                         <?php }  ?>
                                        <input ref="<?php esc_attr_e( 'Insert as Logo','catch-flames' );?>" class="catchflames_upload_image button" name="wsl-image-add" type="button" value="<?php esc_attr_e( 'Change Logo','catch-flames' );?>" />
                               		</div>
                             	</div><!-- .row -->
                                <div class="row">
                                	<div class="col col-1">
                                    	<?php _e( 'Preview:', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-2">
    									<?php
                                        if ( !empty( $options['featured_logo_header'] ) ) {
                                        	echo '<img src="'.esc_url( $options['featured_logo_header'] ).'" alt=""/>';
                                        } else {
                                        	echo '<img src="'. esc_url( get_template_directory_uri() ).'/images/logo.png" alt="" />';
                                        } ?>
                               		</div>
                             	</div><!-- .row -->
                            <?php
                            }
                            ?>
                            <div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                  	<div id="header-featured-image" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Header Featured Image Options', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                      		<div class="row">
                            	<div class="col col-header">
                                	<?php _e( 'Enable Featured Header Image', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-options">
                                	<label title="enable-header-homepage">
                                        <input type="radio" name="catchflames_options[enable_featured_header_image]" id="enable-header-homepage" <?php checked($options['enable_featured_header_image'], 'excludehome'); ?> value="excludehome"  />
                                       <?php _e( 'Excluding Homepage', 'catch-flames' ); ?>
                                    </label>

                                    <label title="enable-header-homepage">
                                        <input type="radio" name="catchflames_options[enable_featured_header_image]" id="enable-header-homepage" <?php checked($options['enable_featured_header_image'], 'homepage'); ?> value="homepage"  />
                                        <?php _e( 'Homepage', 'catch-flames' ); ?>
                                    </label>

                                    <label title="enable-header-allpage">
                                        <input type="radio" name="catchflames_options[enable_featured_header_image]" id="enable-header-allpage" <?php checked($options['enable_featured_header_image'], 'allpage'); ?> value="allpage"  />
                                         <?php _e( 'Entire Site', 'catch-flames' ); ?>
                                    </label>

                                    <label title="enable-header-postpage">
                                        <input type="radio" name="catchflames_options[enable_featured_header_image]" id="enable-header-postpage" <?php checked($options['enable_featured_header_image'], 'postpage'); ?> value="postpage"  />
                                         <?php _e( 'Entire Site, Page/Post Featured Image', 'catch-flames' ); ?>
                                    </label>

                                    <label title="enable-header-pagespostes">
                                        <input type="radio" name="catchflames_options[enable_featured_header_image]" id="enable-header-pagespostes" <?php checked($options['enable_featured_header_image'], 'pagespostes'); ?> value="pagespostes"  />
                                         <?php _e( 'Pages & Posts', 'catch-flames' ); ?>
                                    </label>

                                    <label title="disable-header">
                                        <input type="radio" name="catchflames_options[enable_featured_header_image]" id="disable-header" <?php checked($options['enable_featured_header_image'], 'disable'); ?> value="disable" />
                                         <?php _e( 'Disable', 'catch-flames' ); ?>
                                    </label>
                           		</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Header Image:', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
									<?php
                                    $header_image = get_header_image();
                                    if ( !empty ( $header_image ) ) {
                                    	echo '<a class="button" href="' . admin_url('themes.php?page=custom-header') . '" title="' .esc_attr__( 'Click here to change header image', 'catch-flames' ). '">' . __( 'Click here to change Header Image', 'catch-flames' ) . '</a>';
                                    } else {
                                   		echo '<a class="button" href="' . admin_url('themes.php?page=custom-header') . '" title="' .esc_attr__( 'Click here to change header image', 'catch-flames' ). '">' . __( 'Click here to add Header Image', 'catch-flames' ) . '</a>';
									} ?>
                             	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Preview', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
									<?php
                                    if ( !empty( $header_image ) ) {
                                   		echo '<img src="'.esc_url( $header_image ).'" alt=""  style="width: 90%; height:auto" />';
                                    } else {
                                    	_e( 'There is no Header Image', 'catch-flames' );
                                    } ?>
                             	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Featured Header Image Alt/Title Tag', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                              		<input type="text" size="65" name="catchflames_options[featured_header_image_alt]" value="<?php echo esc_attr( $options['featured_header_image_alt'] ); ?>" />
                               	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Featured Header Image Link URL', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                  	<input type="text" size="65" name="catchflames_options[featured_header_image_url]" value="<?php echo esc_url( $options['featured_header_image_url'] ); ?>" />
                             	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php if( $options['reset_header_image'] == "1" ) { $options['reset_header_image'] = "0"; } ?>
                                	<?php _e( 'Reset Header Featured Image Options?', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type='hidden' value='0' name='catchflames_options[reset_header_image]'>
                                    <input type="checkbox" id="reset_header_image" name="catchflames_options[reset_header_image]" value="1" <?php checked( '1', $options['reset_header_image'] ); ?> /> <?php _e('Check to reset', 'catch-flames'); ?>
                              </div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
						</div><!-- .option-content -->
                 	</div><!-- .option-container -->

                    <div id="header-options" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Menu Options', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                      		<div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Menu Tutorial', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<a class="button" href="<?php echo esc_url( __( 'https://catchthemes.com/blog/custom-menus-wordpress-themes/','catch-flames' ) ); ?>" title="<?php esc_attr_e( 'Menu Tutorial', 'catch-flames' ); ?>" target="_blank"><?php _e( 'Click Here to Read Menu Tutorial', 'catch-flames' );?></a>
                           		</div>
                         	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Custom Menus', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<a class="button" href="<?php echo esc_url( admin_url('nav-menus.php') ); ?>" title="<?php esc_attr_e( 'Click to Create Custom Menus', 'catch-flames' ); ?>"><?php _e( 'Click Here to Create Menu', 'catch-flames' );?></a>
                           		</div>
                         	</div><!-- .row -->
                           	<div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Assign Locations', 'catch-flames' ); ?>
                                     <small><?php _e( 'Note: You can assign your custom menu to Fixed Header Top Menu, Header Right Sidebar Menu, Primary Menu, Secondary Menu and Footer Menu Locations. This will replace the WordPress default page menu', 'catch-flames' ); ?></small>
                                </div>
                                <div class="col col-2">
                                	<a class="button" href="<?php echo admin_url('nav-menus.php?action=locations'); ?>" title="<?php esc_attr_e( 'Click to Manage Menu Locations', 'catch-flames' ); ?>"><?php _e( 'Click to Manage Menu Locations', 'catch-flames' );?></a>
                           		</div>
                         	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Disable Default Page Menu?', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type='hidden' value='0' name='catchflames_options[disable_header_menu]'>
                                   	<input type="checkbox" id="disable_header_menu" name="catchflames_options[disable_header_menu]" value="1" <?php checked( '1', $options['disable_header_menu'] ); ?> /> <?php _e('Check to disable', 'catch-flames'); ?>
                           		</div>
                         	</div><!-- .row -->
                            <div class="row">
                                    <input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                           	</div><!-- .row -->
                       	</div><!-- .option-content -->
                  	</div><!-- .option-container -->

                    <div id="search-settings" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Search Options', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                        	<div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Default Display Text in Search', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type="text" size="45" name="catchflames_options[search_display_text]" value="<?php echo ( isset( $options['search_display_text'] ) ) ? esc_attr( $options['search_display_text'] ) : 'Search'; ?>" />
                             	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div id="layout-options" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Layout Options', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                       		<div class="row">
                            	<div class="col col-header">
                        			<?php _e( 'Default Layout Options', 'catch-flames' ); ?>
                               	</div>
                                <div class="col col-options">
                              		<label title="three-columns" class="box first"><img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>inc/panel/images/three-columns.png" alt="Three Columns" /><br />
                                		<input type="radio" name="catchflames_options[sidebar_layout]" id="three-columns" <?php checked($options['sidebar_layout'], 'three-columns') ?> value="three-columns"  />
                                		<?php _e( 'Three Columns', 'catch-flames' ); ?>
                                	</label>

                                    <label title="right-sidebar" class="box"><img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>inc/panel/images/right-sidebar.png" alt="Content-Sidebar" /><br />
                                    	<input type="radio" name="catchflames_options[sidebar_layout]" id="right-sidebar" <?php checked($options['sidebar_layout'], 'right-sidebar') ?> value="right-sidebar"  />
                                    	<?php _e( 'Right Sidebar', 'catch-flames' ); ?>
                                    </label>

                                    <label title="left-sidebar" class="box"><img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>inc/panel/images/left-sidebar.png" alt="Content-Sidebar" /><br />
                                    	<input type="radio" name="catchflames_options[sidebar_layout]" id="left-sidebar" <?php checked($options['sidebar_layout'], 'left-sidebar') ?> value="left-sidebar"  />
                                    	<?php _e( 'Left Sidebar', 'catch-flames' ); ?>
                                    </label>

                                    <label title="no-sidebar" class="box"><img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>inc/panel/images/no-sidebar.png" alt="Content-Sidebar" /><br />
                                   		<input type="radio" name="catchflames_options[sidebar_layout]" id="no-sidebar" <?php checked($options['sidebar_layout'], 'no-sidebar') ?> value="no-sidebar"  />
                                    	<?php _e( 'No Sidebar', 'catch-flames' ); ?>
                                    </label>
                        		</div>
                            </div><!-- .row -->
                         	<div class="row">
                            	<div class="col col-header">
                        			<?php _e( 'Archive Content Layout', 'catch-flames' ); ?>
                               	</div>
                                <div class="col col-options">
									<label title="content-excerpt" class="box first"><img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>inc/panel/images/excerpt-blog.jpg" alt="Excerpt/Blog Display" /><br />
                                		<input type="radio" name="catchflames_options[content_layout]" id="content-excerpt" <?php checked($options['content_layout'], 'excerpt-border') ?> value="excerpt-border"  />
                                		<?php _e( 'Excerpt/Blog Display', 'catch-flames' ); ?>
                                	</label>

                                    <label title="content-full" class="box"><img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>inc/panel/images/full-content.jpg" alt="Full Content Display" /><br />
                                    	<input type="radio" name="catchflames_options[content_layout]" id="content-full" <?php checked($options['content_layout'], 'full') ?> value="full"  />
                                    <?php _e( 'Full Content Display', 'catch-flames' ); ?>
                                    </label>
                              	</div>
                            </div><!-- .row -->
                            <div class="row">
                            	<div class="col col-header">
                                	<?php if( $options['reset_sidebar_layout'] == "1" ) { $options['reset_sidebar_layout'] = "0"; } ?>
                                	<?php _e( 'Reset Layout?', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-options">
                                	<input type='hidden' value='0' name='catchflames_options[reset_sidebar_layout]'>
                                    <input type="checkbox" id="reset_family" name="catchflames_options[reset_sidebar_layout]" value="1" <?php checked( '1', $options['reset_sidebar_layout'] ); ?> /> <?php _e('Check to reset', 'catch-flames'); ?>
                              	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div id="homepage-category-setting" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Homepage / Frontpage Category Setting', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                       		<div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Front page posts categories:', 'catch-flames' ); ?>
                                    <p><small><?php _e( 'Only posts that belong to the categories selected here will be displayed on the front page.', 'catch-flames' ); ?></small></p>
                                </div>
                                <div class="col col-2">
                                    <select name="catchflames_options[front_page_category][]" id="frontpage_posts_cats" multiple="multiple" class="select-multiple">
                                        <option value="0" <?php if ( empty( $options['front_page_category'] ) ) { echo 'selected="selected"'; } ?>><?php _e( '--Disabled--', 'catch-flames' ); ?></option>
                                        <?php /* Get the list of categories */
                                            $categories = get_categories();
                                            if( empty( $options['front_page_category'] ) ) {
                                                $options['front_page_category'] = array();
                                            }
                                            foreach ( $categories as $category) :
                                        ?>
                                        <option value="<?php echo $category->cat_ID; ?>" <?php if ( in_array( $category->cat_ID, $options['front_page_category'] ) ) {echo 'selected="selected"';}?>><?php echo $category->cat_name; ?></option>
                                        <?php endforeach; ?>
                                    </select><br />
                                    <span class="description"><?php _e( 'You may select multiple categories by holding down the CTRL key.', 'catch-flames' ); ?></span>
                               	</div>
                          	</div><!-- .row -->
                         	<div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                            </div><!-- .row -->
                        </div><!-- .option-content -->
                  	</div><!-- .option-container -->

                 	<div id="excerpt-more-tag" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Excerpt / More Tag Settings', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                       		<div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'More Tag Text', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type="text" size="45" name="catchflames_options[more_tag_text]" value="<?php echo ( isset( $options['more_tag_text'] ) ) ? esc_attr( $options['more_tag_text'] ) : 'Continue Reading &rarr;'; ?>" />
                             	</div>
                          	</div><!-- .row -->
                        	<div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Excerpt length(words)', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type="text" size="3" name="catchflames_options[excerpt_length]" value="<?php echo intval( $options['excerpt_length'] ); ?>" />
                             	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<div class="col col-1">
                                	<?php if( $options['reset_more_tag'] == "1" ) { $options['reset_more_tag'] = "0"; } ?>
                                	<?php _e( 'Reset Excerpt?', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type='hidden' value='0' name='catchflames_options[reset_more_tag]'>
                                  	<input type="checkbox" id="reset_more_tag" name="catchflames_options[reset_more_tag]" value="1" <?php checked( '1', $options['reset_more_tag'] ); ?> /> <?php _e('Check to reset', 'catch-flames'); ?>
                              	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

					<?php
                    // @remove if block when WP 5.0 is released
                    if ( ! function_exists( 'wp_update_custom_css_post' ) ) {
                    ?>
                        <div id="custom-css" class="option-container">
                            <h3 class="option-toggle"><a href="#"><?php _e( 'Custom CSS', 'catch-flames' ); ?></a></h3>
                            <div class="option-content inside">
                            	<div class="row">
                                	<div class="col col-1">
                                    	<?php _e( 'Enter your custom CSS styles.', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-2">
                                    	<textarea name="catchflames_options[custom_css]" id="custom-css" cols="90" rows="12"><?php echo esc_attr( $options['custom_css'] ); ?></textarea>
                                	</div>
                              	</div><!-- .row -->
                            	<div class="row">
                                	<div class="col col-1">
                                    	<?php _e( 'CSS Tutorial from W3Schools.', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-2">
                                    	<a class="button" href="<?php echo esc_url( __( 'http://www.w3schools.com/css/default.asp','catch-flames' ) ); ?>" title="<?php esc_attr_e( 'CSS Tutorial', 'catch-flames' ); ?>" target="_blank"><?php _e( 'Click Here to Read', 'catch-flames' );?></a>
                                	</div>
                              	</div><!-- .row -->
                                <div class="row">
                                	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                              	</div><!-- .row -->
                            </div><!-- .option-content -->
                        </div><!-- .option-container -->
                     <?php
                    }
                    ?>

                    <div id="scrollup" class="option-container">
                    	<h3 class="option-toggle"><a href="#"><?php _e( 'Scroll Up', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                        	<div class="row">
                            	<div class="col col-1">
									<?php _e( 'Disable Scroll Up?', 'catch-flames' ); ?></th>
                                </div>
                                <div class="col col-2">
                                        <input type='hidden' value='0' name='catchflames_options[disable_scrollup]'>
                                        <input type="checkbox" id="headerlogo" name="catchflames_options[disable_scrollup]" value="1" <?php checked( '1', $options['disable_scrollup'] ); ?> /> <?php _e('Check to disable', 'catch-flames'); ?>
                                 </div>
                          	</div><!-- .row -->
                      		<div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->
                </div><!-- #themeoptions -->

				<!-- Option for Color Options -->
                <div id="color-options">
                	<div id="color-scheme" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Color Scheme', 'catch-flames' ); ?></a></h3>
                        <div class="option-content show inside">
                        	<div class="row">
                            	<div class="col col-header">
                        			<?php _e( 'Default Color Scheme', 'catch-flames' ); ?>
                               	</div>
                                <div class="col col-options">
                                    <label title="color-light" class="box first"><img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>inc/panel/images/light.jpg" alt="color-light" /><br />
                                    	<input type="radio" name="catchflames_options[color_scheme]" id="color-light" <?php checked($options['color_scheme'], 'light') ?> value="light"  />
                                    	<?php _e( 'Light', 'catch-flames' ); ?>
                                    </label>
                                    <label title="color-dark" class="box"><img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>inc/panel/images/dark.jpg" alt="color-dark" /><br />
                                    	<input type="radio" name="catchflames_options[color_scheme]" id="color-dark" <?php checked($options['color_scheme'], 'dark') ?> value="dark"  />
                                    	<?php _e( 'Dark', 'catch-flames' ); ?>
                                    </label>
                              	</div>
                          	</div><!-- .row -->
                            <div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
                  		</div><!-- .option-content -->
                  	</div><!-- #color-scheme -->
                </div><!-- #color-options -->

                <div id="contentsettings">
                        <div id="homepage-featured-content" class="option-container">
                            <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Content Options', 'catch-flames' ); ?></a></h3>
                            <div class="option-content inside">
                                <div class="row">
                                    <div class="col col-header">
                                        <?php _e( 'Select Content Type', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-options">
                                        <?php
                                        $featured_content_types = array(
                                                                    'demo-featured-content' => __( 'Demo Content', 'catch-flames' ),
                                                                    'featured-page-content' => __( 'Featured Page Content', 'catch-flames' )
                                                                );
                                        foreach( $featured_content_types as $key => $value ) : ?>
                                            <label title="<?php echo $value; ?>">
                                                <input type="radio" name="catchflames_options[featured_content_type]" id="<?php echo $key; ?>" <?php checked($options['featured_content_type'], $key ); ?> value="<?php echo $key; ?>"  />
                                                <?php echo $value; ?>
                                            </label>
                                        <?php endforeach; ?>
                                    </div>
                                </div><!-- .row -->

                                <div class="row">
                                    <div class="col col-header">
                                        <?php _e( 'Enable Content', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-options">
                                        <label title="<?php _e( 'Homepage', 'catch-flames' ); ?>">
                                            <input type="radio" name="catchflames_options[featured_content_option]" id="homepage" <?php checked($options['featured_content_option'], 'homepage'); ?> value="homepage"  />
                                            <?php _e( 'Homepage', 'catch-flames' ); ?>
                                        </label>

                                        <label title="<?php _e( 'Entire Site', 'catch-flames' ); ?>">
                                            <input type="radio" name="catchflames_options[featured_content_option]" id="entire-site" <?php checked($options['featured_content_option'], 'entire-site'); ?> value="entire-site"  />
                                            <?php _e( 'Entire Site', 'catch-flames' ); ?>
                                        </label>

                                        <label title="<?php _e( 'Disable', 'catch-flames' ); ?>">
                                            <input type="radio" name="catchflames_options[featured_content_option]" id="disabled" <?php checked($options['featured_content_option'], 'disabled'); ?> value="disabled"  />
                                            <?php _e( 'Disable', 'catch-flames' ); ?>
                                        </label>
                                    </div>
                                </div><!-- .row -->

                                <div class="row">
                                    <div class="col col-1">
                                        <?php _e( 'Headline', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-2">
                                        <input type="text" size="65" name="catchflames_options[featured_content_headline]" value="<?php echo esc_attr( $options['featured_content_headline'] ); ?>" /> <?php _e( 'Leave empty if you want to remove headline', 'catch-flames' ); ?>
                                    </div>
                                </div><!-- .row -->

                                <div class="row">
                                    <div class="col col-1">
                                        <?php _e( 'Sub Headline', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-2">
                                        <input type="text" size="65" name="catchflames_options[featured_content_subheadline]" value="<?php echo esc_attr( $options['featured_content_subheadline'] ); ?>" /> <?php _e( 'Leave empty if you want to remove headline', 'catch-flames' ); ?>
                                    </div>
                                </div><!-- .row -->

                                <div class="row">
                                    <div class="col col-1">
                                        <?php _e( 'Number of Featured Content', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-2">
                                        <input type="text" size="2" name="catchflames_options[featured_content_number]" value="<?php echo intval( $options['featured_content_number'] ); ?>" size="2" />
                                    </div>
                                </div><!-- .row -->

                                <div class="row">
                                    <div class="col col-header">
                                        <?php _e( 'Featured Content Layout', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-options">
                                        <label title="layout-two" class="box first">
                                        <input type="radio" name="catchflames_options[featured_content_layout]" id="layout-two" <?php checked($options['featured_content_layout'], 'layout-two'); ?> value="layout-two"  />
                                        <?php _e( '2 Columns', 'catch-flames' ); ?>
                                        </label>

                                        <label title="layout-three" class="box">
                                        <input type="radio" name="catchflames_options[featured_content_layout]" id="layout-three" <?php checked($options['featured_content_layout'], 'layout-three'); ?> value="layout-three"  />
                                        <?php _e( '3 Columns', 'catch-flames' ); ?>
                                        </label>

                                        <label title="layout-four" class="box">
                                        <input type="radio" name="catchflames_options[featured_content_layout]" id="layout-four" <?php checked($options['featured_content_layout'], 'layout-four'); ?> value="layout-four"  />
                                        <?php _e( '4 Columns', 'catch-flames' ); ?>
                                        </label>

                                    </div>
                                </div><!-- .row -->

                                <div class="row">
                                    <div class="col col-header">
                                        <?php _e( 'Display Content', 'catch-flames' ); ?>
                                    </div>
                                    <div class="col col-options">
                                        <label title="excerpt" class="box first">
                                        <input type="radio" name="catchflames_options[featured_content_show]" id="show-excerpt" <?php checked($options['featured_content_show'], 'excerpt'); ?> value="excerpt"  />
                                        <?php _e( 'Show Excerpt', 'catch-flames' ); ?>
                                        </label>

                                        <label title="full-content" class="box">
                                        <input type="radio" name="catchflames_options[featured_content_show]" id="full-content" <?php checked($options['featured_content_show'], 'full-content'); ?> value="full-content"  />
                                        <?php _e( 'Show Full Content', 'catch-flames' ); ?>
                                        </label>

                                        <label title="hide-content" class="box">
                                        <input type="radio" name="catchflames_options[featured_content_show]" id="hide-content" <?php checked($options['featured_content_show'], 'hide-content'); ?> value="hide-content"  />
                                        <?php _e( 'Hide Content', 'catch-flames' ); ?>
                                        </label>

                                    </div>
                                </div><!-- .row -->

                                <div class="row">
                                    <input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                                </div><!-- .row -->
                            </div><!-- .option-content -->
                        </div><!-- .option-container -->

                        <div class="option-container page-content">
                            <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Page Content Options', 'catch-flames' ); ?></a></h3>
                            <div class="option-content inside">
                               <?php for ( $i = 1; $i <= $options['featured_content_number']; $i++ ): ?>
                                    <div class="row">
                                            <div class="col col-1">
                                                <?php printf( esc_attr__( 'Featured Page Content #%s', 'catch-flames' ), $i ); ?>
                                            </div>
                                            <div class="col col-2">
                                                 <?php
                                                    $catchflames_name = 'catchflames_options[featured_content_page][' . absint( $i ) . ']';
                                                    $catchflames_args = array(
                                                                    'depth'             => 0,
                                                                    'child_of'          => 0,
                                                                    'selected'          => ( isset( $options['featured_content_page'][ $i ] ) && $options['featured_content_page'][ $i ] > 0 ) ? $options['featured_content_page'][ $i ] : '',
                                                                    'echo'              => 1,
                                                                    'name'              => $catchflames_name,
                                                                    'id'                => $catchflames_name,
                                                                    'show_option_none' => '--Select One--',
                                                                );
                                                   wp_dropdown_pages( $catchflames_args );
                                                ?>
                                                <?php if( isset( $options['featured_content_page'][ $i ] ) && $options['featured_content_page'][ $i ] > 0 ) : ?>
                                                    <a href="<?php bloginfo ( 'url' );?>/wp-admin/post.php?post=<?php if( array_key_exists ( 'featured_content_page', $options ) && array_key_exists ( $i, $options['featured_content_page'] ) ) echo absint( $options['featured_content_page'][ $i ] ); ?>&action=edit" class="button" title="<?php esc_attr_e( 'Click Here To Edit', 'catch-flames' ); ?>" target="_blank"><?php _e( 'Click Here To Edit', 'catch-flames' ); ?></a>
                                                <?php endif; ?>
                                            </div>
                                        </div><!-- .row -->
                                <?php endfor; ?>

                                <div class="row">
                                    <input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                                </div><!-- .row -->
                            </div><!-- .option-content -->
                        </div><!-- .option-container -->

                </div><!-- #contentsettings -->

                <!-- Option for Slider Options -->
                <div id="slidersettings">
                	<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Slider Options', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                        	<div class="row">
                            	<div class="col col-header">
                                	<?php _e( 'Select Slider Type', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-options">
                                	<label title="demo-slider">
                                    	<input type="radio" name="catchflames_options[select_slider_type]" id="demo-slider" <?php checked($options['select_slider_type'], 'demo-slider'); ?> value="demo-slider"  />
                                    	<?php _e( 'Demo Slider', 'catch-flames' ); ?>
                                    </label>

                                    <label title="page-slider">
                                   		<input type="radio" name="catchflames_options[select_slider_type]" id="page-slider" <?php checked($options['select_slider_type'], 'page-slider') ?> value="page-slider"  />
                                    	<?php _e( 'Featured Page Slider', 'catch-flames' ); ?>
                                    </label>
                                </div>
                          	</div><!-- .row -->

                			<div class="row">
                            	<div class="col col-header">
                        			<?php _e( 'Enable Sidebar', 'catch-flames' ); ?>
                               	</div>
                                <div class="col col-options">
                                    <label title="enable-slider-homepager">
                                    	<input type="radio" name="catchflames_options[enable_slider]" id="enable-slider-homepage" <?php checked($options['enable_slider'], 'enable-slider-homepage') ?> value="enable-slider-homepage"  />
                                    	<?php _e( 'Homepage / Frontpage', 'catch-flames' ); ?>
                                    </label>

                                    <label title="enable-slider-allpage">
                                    	<input type="radio" name="catchflames_options[enable_slider]" id="enable-slider-allpage" <?php checked($options['enable_slider'], 'enable-slider-allpage') ?> value="enable-slider-allpage"  />
                                  		<?php _e( 'Entire Site', 'catch-flames' ); ?>
                                    </label>

                                    <label title="disable-slider">
                                    	<input type="radio" name="catchflames_options[enable_slider]" id="disable-slider" <?php checked($options['enable_slider'], 'disable-slider') ?> value="disable-slider"  />
                                     	<?php _e( 'Disable', 'catch-flames' ); ?>
                                   	</label>
                           		</div>
                         	</div><!-- .row -->

                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Number of Slides', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                	<input type="text" name="catchflames_options[slider_qty]" value="<?php echo intval( $options['slider_qty'] ); ?>" size="2" />
                             	</div>
                          	</div><!-- .row -->

                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Transition Effect:', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                    <select id="catchflames_cycle_style" name="catchflames_options[transition_effect]">
                                        <option value="fade" <?php selected('fade', $options['transition_effect']); ?>><?php _e( 'fade', 'catch-flames' ); ?></option>
                                        <option value="wipe" <?php selected('wipe', $options['transition_effect']); ?>><?php _e( 'wipe', 'catch-flames' ); ?></option>
                                        <option value="scrollUp" <?php selected('scrollUp', $options['transition_effect']); ?>><?php _e( 'scrollUp', 'catch-flames' ); ?></option>
                                        <option value="scrollDown" <?php selected('scrollDown', $options['transition_effect']); ?>><?php _e( 'scrollDown', 'catch-flames' ); ?></option>
                                        <option value="scrollLeft" <?php selected('scrollLeft', $options['transition_effect']); ?>><?php _e( 'scrollLeft', 'catch-flames' ); ?></option>
                                        <option value="scrollRight" <?php selected('scrollRight', $options['transition_effect']); ?>><?php _e( 'scrollRight', 'catch-flames' ); ?></option>
                                        <option value="blindX" <?php selected('blindX', $options['transition_effect']); ?>><?php _e( 'blindX', 'catch-flames' ); ?></option>
                                        <option value="blindY" <?php selected('blindY', $options['transition_effect']); ?>><?php _e( 'blindY', 'catch-flames' ); ?></option>
                                        <option value="blindZ" <?php selected('blindZ', $options['transition_effect']); ?>><?php _e( 'blindZ', 'catch-flames' ); ?></option>
                                        <option value="cover" <?php selected('cover', $options['transition_effect']); ?>><?php _e( 'cover', 'catch-flames' ); ?></option>
                                        <option value="shuffle" <?php selected('shuffle', $options['transition_effect']); ?>><?php _e( 'shuffle', 'catch-flames' ); ?></option>
                                    </select>
                             	</div>
                          	</div><!-- .row -->

                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Transition Delay', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                            		<input type="text" name="catchflames_options[transition_delay]" value="<?php echo $options['transition_delay']; ?>" size="2" />
                                   	<span class="description"><?php _e( 'second(s)', 'catch-flames' ); ?></span>
                            	</div>
                          	</div><!-- .row -->

                            <div class="row">
                            	<div class="col col-1">
                                	<?php _e( 'Transition Length', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                            		<input type="text" name="catchflames_options[transition_duration]" value="<?php echo $options['transition_duration']; ?>" size="2" />
                                        <span class="description"><?php _e( 'second(s)', 'catch-flames' ); ?></span>
                            	</div>
                          	</div><!-- .row -->
                            <div class="row">
                                <div class="col col-1">
                                    <?php _e( 'Image Loader', 'catch-flames' ); ?>
                                </div>
                                <div class="col col-2">
                                    <select id="catchflames_cycle_style" name="catchflames_options[image_loader]">

                                        <?php $image_loader_options = catchflames_image_loader_options();

                                        foreach ( $image_loader_options as $key => $value) {
                                            echo '<option value="' . $key .'" '. selected( $key, $options['image_loader'] ) . '>' . $value . '</option>';
                                        }
                                    ?>
                                    </select>
                                </div>
                            </div><!-- .row -->
							<div class="row">
        						<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                          	</div><!-- .row -->
                        </div><!-- .option-content -->
            		</div><!-- .option-container -->

        			<div id="featured-page-slider" class="option-container page-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Page Slider Options', 'catch-flames' ); ?></a></h3>
                        <div class="option-content inside">
                            <?php for ( $i = 1; $i <= $options['slider_qty']; $i++ ): ?>
                                <div class="repeat-content-wrap">
                                    <div class="row">
                                        <div class="col col-1">
                                            <?php printf( esc_attr__( 'Featured Page Slider #%s', 'catch-flames' ), $i ); ?>
                                        </div>
                                        <div class="col col-2">
                                            <?php
                                                $catchflames_name = 'catchflames_options[featured_slider_page][' . absint( $i ) . ']';
                                                $catchflames_args = array(
                                                                'depth'             => 0,
                                                                'child_of'          => 0,
                                                                'selected'          => ( isset( $options['featured_slider_page'][ $i ] ) && $options['featured_slider_page'][ $i ] > 0 ) ? $options['featured_slider_page'][ $i ] : '',
                                                                'echo'              => 1,
                                                                'name'              => $catchflames_name,
                                                                'id'                => $catchflames_name,
                                                                'show_option_none' => '--Select One--',
                                                            );
                                               wp_dropdown_pages( $catchflames_args );
                                            ?>
                                        <?php if( isset( $options['featured_slider_page'][ $i ] ) && $options['featured_slider_page'][ $i ] > 0 ) : ?>
                                            <a href="<?php bloginfo ( 'url' );?>/wp-admin/post.php?post=<?php if( array_key_exists ( 'featured_slider_page', $options ) && array_key_exists ( $i, $options['featured_slider_page'] ) ) echo absint( $options['featured_slider_page'][ $i ] ); ?>&action=edit" class="button" title="<?php esc_attr_e('Click Here To Edit', 'catch-flames' ); ?>" target="_blank"><?php _e( 'Click Here To Edit', 'catch-flames' ); ?></a>
                                        <?php endif; ?>
                                        </div>
                                    </div><!-- .row -->
                                </div><!-- .repeat-content-wrap -->
                         	<?php endfor; ?>
                            <div class="row">
                            	<input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                           	</div><!-- .row -->
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->
                </div><!-- #slidersettings -->

                <!-- Options for Social Links -->
                <div id="sociallinks" class="option-container">
                    <h3 class="option-toggle"><a href="#"><?php _e( 'Social Icons', 'catch-flames' ); ?></a></h3>
                    <div class="option-content show inside">
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Enable Social Icons in Sidebar?', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <a class="button" href="<?php echo admin_url('widgets.php'); ?>" title="<?php esc_attr_e( 'Just add Catch Flames Social Widget in Sidebar', 'catch-flames' ); ?>"><?php _e( 'Just add Catch Flames Social Widget in Sidebar', 'catch-flames' );?></a>
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Enable Social Icons in Footer?', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type='hidden' value='0' name='catchflames_options[disable_footer_social]'>
                                <input type="checkbox" id="headerlogo" name="catchflames_options[disable_footer_social]" value="1" <?php checked( '1', $options['disable_footer_social'] ); ?> /> <?php _e('Check to enable', 'catch-flames'); ?>
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Facebook', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_facebook]" value="<?php echo esc_url( $options['social_facebook'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Twitter', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_twitter]" value="<?php echo esc_url( $options['social_twitter'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Google+', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_googleplus]" value="<?php echo esc_url( $options['social_googleplus'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Pinterest', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_pinterest]" value="<?php echo esc_url( $options['social_pinterest'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Youtube', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_youtube]" value="<?php echo esc_url( $options['social_youtube'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Vimeo', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_vimeo]" value="<?php echo esc_url( $options['social_vimeo'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Linkedin', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_linkedin]" value="<?php echo esc_url( $options['social_linkedin'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'AIM', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_aim]" value="<?php echo esc_url( $options['social_aim'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'MySpace', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_myspace]" value="<?php echo esc_url( $options['social_myspace'] ); ?>" />
                            </div>
                        </div><!-- .row -->

                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Flickr', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_flickr]" value="<?php echo esc_url( $options['social_flickr'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Tumblr', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_tumblr]" value="<?php echo esc_url( $options['social_tumblr'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'deviantART', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_deviantart]" value="<?php echo esc_url( $options['social_deviantart'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Dribbble', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_dribbble]" value="<?php echo esc_url( $options['social_dribbble'] ); ?>" />
                            </div>
                        </div><!-- .row -->

                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'WordPress', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_wordpress]" value="<?php echo esc_url( $options['social_wordpress'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'RSS', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_rss]" value="<?php echo esc_url( $options['social_rss'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Slideshare', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_slideshare]" value="<?php echo esc_url( $options['social_slideshare'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Instagram', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_instagram]" value="<?php echo esc_url( $options['social_instagram'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Skype', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_skype]" value="<?php echo esc_attr( $options['social_skype'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Soundcloud', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_soundcloud]" value="<?php echo esc_url( $options['social_soundcloud'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Email', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_email]" value="<?php echo sanitize_email( $options['social_email'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Contact', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_contact]" value="<?php echo esc_url( $options['social_contact'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Xing', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_xing]" value="<?php echo esc_url( $options['social_xing'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Meetup', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_meetup]" value="<?php echo esc_url( $options['social_meetup'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Goodreads', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_goodreads]" value="<?php echo esc_url( $options['social_goodreads'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'github', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type="text" size="45" name="catchflames_options[social_github]" value="<?php echo esc_url( $options['social_github'] ); ?>" />
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <div class="col col-1">
                                <?php _e( 'Enable SpecificFeeds?', 'catch-flames' ); ?>
                            </div>
                            <div class="col col-2">
                                <input type='hidden' value='0' name='catchflames_options[enable_specificfeeds]'>
                                <input type="checkbox" id="headerlogo" name="catchflames_options[enable_specificfeeds]" value="1" <?php checked( '1', $options['enable_specificfeeds'] ); ?> /> <?php _e('Check to enable', 'catch-flames'); ?>
                            </div>
                        </div><!-- .row -->
                        <div class="row">
                            <input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-flames' ); ?>" />
                        </div><!-- .row -->
                  	</div><!-- .option-content -->

                </div><!-- #sociallinks -->

            </div><!-- #catchflames_ad_tabs -->
		</form>
	</div><!-- .wrap -->
<?php
}


/**
 * Validate content options
 * @param array $options
 * @uses esc_url_raw, absint, esc_textarea, sanitize_text_field, catchflames_invalidate_caches
 * @return array
 */
function catchflames_theme_options_validate( $options ) {
	global $catchflames_options_settings;
    $input_validated = $catchflames_options_settings;

	global $catchflames_options_defaults;
	$defaults = $catchflames_options_defaults;

    if( "1" == $options['reset_all_settings'] ) {
        return $defaults;
    }

	$fonts = catchflames_available_fonts();
	$units = array( 'px', 'pt', 'em', '%' );

    $input = array();
    $input = $options;

	// data validation for scroll up
	if ( isset( $input['disable_scrollup'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_scrollup' ] = $input[ 'disable_scrollup' ];
	}

	// data validation for logo
	if ( isset( $input[ 'featured_logo_header' ] ) ) {
		$input_validated[ 'featured_logo_header' ] = esc_url_raw( $input[ 'featured_logo_header' ] );
	}
	if ( isset( $input['remove_header_logo'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'remove_header_logo' ] = $input[ 'remove_header_logo' ];
	}

	// data validation for Search Settings
	if ( isset( $input[ 'search_display_text' ] ) ) {
        $input_validated[ 'search_display_text' ] = sanitize_text_field( $input[ 'search_display_text' ] );
    }

    // Data validation for Promotion Headline
    if ( isset( $input['promotion_headline_option'] ) ) {
        $input_validated[ 'promotion_headline_option' ] = $input[ 'promotion_headline_option' ];
    }
    if ( isset( $input['promotion_headline_left_width'] ) ) {
        $input_validated[ 'promotion_headline_left_width' ] = absint ( $input[ 'promotion_headline_left_width' ] );
    }
    if ( isset( $input[ 'promotion_headline' ] ) ) {
        $input_validated[ 'promotion_headline' ] = wp_kses_post ( $input[ 'promotion_headline' ] );
    }
    if ( isset( $input['promotion_subheadline'] ) ) {
        $input_validated[ 'promotion_subheadline' ] = wp_kses_post ( $input[ 'promotion_subheadline' ] );
    }
    if ( isset( $input['promotion_headline_button'] ) ) {
        $input_validated[ 'promotion_headline_button' ] = sanitize_text_field ( $input[ 'promotion_headline_button' ] );
    }
    if ( isset( $input['promotion_headline_url'] ) ) {
        $input_validated[ 'promotion_headline_url' ] = esc_url_raw ( $input[ 'promotion_headline_url' ] );
    }
    if ( isset( $input['promotion_headline_target'] ) ) {
        $input_validated[ 'promotion_headline_target' ] = $input[ 'promotion_headline_target' ];
    }

	// Data validation for Fixed Header Top Options
	if ( isset( $input['enable_header_top'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'enable_header_top' ] = $input[ 'enable_header_top' ];
	}
	if ( isset( $input['disable_top_menu_logo'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_top_menu_logo' ] = $input[ 'disable_top_menu_logo' ];
	}
	if ( isset( $input[ 'top_menu_logo' ] ) ) {
		$input_validated[ 'top_menu_logo' ] = esc_url_raw( $input[ 'top_menu_logo' ] );
	}

	// data validation for Header Featured Image Options
	if ( isset( $input[ 'enable_featured_header_image' ] ) ) {
		$input_validated[ 'enable_featured_header_image' ] = $input[ 'enable_featured_header_image' ];
	}
	if ( isset( $input[ 'featured_header_image_alt' ] ) ) {
		$input_validated[ 'featured_header_image_alt' ] = sanitize_text_field( $input[ 'featured_header_image_alt' ] );
	}
	if ( isset( $input[ 'featured_header_image_url' ] ) ) {
		$input_validated[ 'featured_header_image_url' ] = esc_url_raw( $input[ 'featured_header_image_url' ] );
	}

	if ( isset( $input['reset_header_image'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_header_image' ] = $input[ 'reset_header_image' ];

		if ( $input['reset_header_image'] == '1' ) {
            $input_validated[ 'enable_featured_header_image' ] = $defaults[ 'enable_featured_header_image' ];
            $input_validated[ 'featured_header_image_alt' ]    = $defaults[ 'featured_header_image_alt' ];
            $input_validated[ 'featured_header_image_url' ]    = $defaults[ 'featured_header_image_url' ];
            $input_validated[ 'reset_header_image' ]           = "0";
		}
	}

	// data validation for Disable Primary Menu
	if ( isset( $input['disable_header_menu'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_header_menu' ] = $input[ 'disable_header_menu' ];
	}

	// data validation for Color Scheme
	if ( isset( $input['color_scheme'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'color_scheme' ] = $input[ 'color_scheme' ];
	}

    // data validation for Default Layout verification
	if ( isset( $input[ 'sidebar_layout' ] ) ) {
		$input_validated[ 'sidebar_layout' ] = $input[ 'sidebar_layout' ];
	}
   // data validation for Homepage Content Layout verification
	if ( isset( $input[ 'content_layout' ] ) ) {
		$input_validated[ 'content_layout' ] = $input[ 'content_layout' ];
	}
	if ( isset( $input['reset_sidebar_layout'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_sidebar_layout' ] = $input[ 'reset_sidebar_layout' ];

		if ( $input['reset_sidebar_layout'] == 1 ) {
            $input_validated[ 'sidebar_layout' ]       = $defaults[ 'sidebar_layout' ];
            $input_validated[ 'content_layout' ]       = $defaults[ 'content_layout' ];
            $input_validated[ 'reset_sidebar_layout' ] = "0";
		}
	}


	// Data Validation for Custom CSS Style
    // @remove if block when WP 5.0 is released
    if ( ! function_exists( 'wp_update_custom_css_post' )  && isset( $input['custom_css'] ) ) {
        $input_validated['custom_css'] = wp_kses_stripslashes($input['custom_css']);
    }

	// data validation for Homepage/Frontpage posts categories
    if ( isset( $input['front_page_category' ] ) ) {
        if( in_array( 0, $input['front_page_category' ] ) ) {
            $input_validated['front_page_category'] = '0';
        }
        else {
		    $input_validated['front_page_category'] = $input['front_page_category'];
        }
    }

	// data validation for More Tags and Excerpt Length
    if ( isset( $input[ 'more_tag_text' ] ) ) {
        $input_validated[ 'more_tag_text' ] = sanitize_text_field ( $input[ 'more_tag_text' ] );
    }
    //data validation for excerpt length
    if ( isset( $input[ 'excerpt_length' ] ) ) {
        $input_validated[ 'excerpt_length' ] = absint( $input[ 'excerpt_length' ] ) ? $input [ 'excerpt_length' ] : 30;
    }
   //data validation for reset more
	if ( isset( $input['reset_moretag'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_moretag' ] = $input[ 'reset_moretag' ];

		if( $input['reset_moretag'] == 1 ) {
            global $catchflames_options_defaults;
            $defaults                            = $catchflames_options_defaults;
            $input_validated[ 'more_tag_text' ]  = $defaults[ 'more_tag_text' ];
            $input_validated[ 'excerpt_length' ] = $defaults[ 'excerpt_length' ];
            $input_validated[ 'reset_moretag' ] = "0";
		}
	}

    if ( isset( $input['exclude_slider_post'] ) ) {
        // Our checkbox value is either 0 or 1
   		$input_validated[ 'exclude_slider_post' ] = $input[ 'exclude_slider_post' ];

    }

	// data validation Slider Options

	// data validation for Slider Type
	if( isset( $input[ 'select_slider_type' ] ) ) {
		$input_validated[ 'select_slider_type' ] = $input[ 'select_slider_type' ];
	}
	if( isset( $input[ 'select_slider_layout' ] ) ) {
		$input_validated[ 'select_slider_layout' ] = $input[ 'select_slider_layout' ];
	}
	// data validation for Enable Slider
	if( isset( $input[ 'enable_slider' ] ) ) {
		$input_validated[ 'enable_slider' ] = $input[ 'enable_slider' ];
	}
    // data validation for number of slides
	if ( isset( $input[ 'slider_qty' ] ) ) {
		$input_validated[ 'slider_qty' ] = absint( $input[ 'slider_qty' ] ) ? $input [ 'slider_qty' ] : 4;
	}
    // data validation for transition effect
    if( isset( $input[ 'transition_effect' ] ) ) {
        $input_validated['transition_effect'] = wp_filter_nohtml_kses( $input['transition_effect'] );
    }
    // data validation for transition delay
    if ( isset( $input[ 'transition_delay' ] ) && is_numeric( $input[ 'transition_delay' ] ) ) {
        $input_validated[ 'transition_delay' ] = $input[ 'transition_delay' ];
    }
    // data validation for transition length
    if ( isset( $input[ 'transition_duration' ] ) && is_numeric( $input[ 'transition_duration' ] ) ) {
        $input_validated[ 'transition_duration' ] = $input[ 'transition_duration' ];
    }
    // data validation for transition length
    if ( isset( $input[ 'image_loader' ] ) ) {
        $input_validated[ 'image_loader' ] = sanitize_key( $input[ 'image_loader' ] );
    }

	// data validation for Featured Page and Page Slider
	if ( isset( $input[ 'featured_slider_page' ] ) ) {
		$input_validated[ 'featured_slider_page' ] = array();
	}
 	if ( isset( $input[ 'slider_qty' ] ) )	{
		for ( $i = 1; $i <= $input [ 'slider_qty' ]; $i++ ) {
			if ( !empty( $input[ 'featured_slider_page' ][ $i ] ) && intval( $input[ 'featured_slider_page' ][ $i ] ) ) {
				$input_validated[ 'featured_slider_page' ][ $i ] = absint($input[ 'featured_slider_page' ][ $i ] );
			}
		}
	}

	// data validation for Featured Image Slider
	if ( isset( $input[ 'featured_image_slider_image' ] ) ) {
		$input_validated[ 'featured_image_slider_image' ] = array();
	}
	if ( isset( $input[ 'featured_image_slider_link' ] ) ) {
		$input_validated[ 'featured_image_slider_link' ] = array();
	}
	if ( isset( $input[ 'featured_image_slider_base' ] ) ) {
		$input_validated[ 'featured_image_slider_base' ] = array();
	}
	if ( isset( $input[ 'featured_image_slider_title' ] ) ) {
		$input_validated[ 'featured_image_slider_title' ] = array();
	}
	if ( isset( $input[ 'featured_image_slider_content' ] ) ) {
		$input_validated[ 'featured_image_slider_content' ] = array();
	}
 	if ( isset( $input[ 'slider_qty' ] ) )	{
		for ( $i = 1; $i <= $input [ 'slider_qty' ]; $i++ ) {
			if ( !empty( $input[ 'featured_image_slider_image' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_image' ][ $i ] = esc_url_raw($input[ 'featured_image_slider_image' ][ $i ] );
			}
			if ( !empty( $input[ 'featured_image_slider_link' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_link'][ $i ] = esc_url_raw($input[ 'featured_image_slider_link'][ $i ]);
			}
			if ( !empty( $input[ 'featured_image_slider_base' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_base'][ $i ] = $input[ 'featured_image_slider_base'][ $i ];
			}
			if ( !empty( $input[ 'featured_image_slider_title' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_title'][ $i ] = sanitize_text_field($input[ 'featured_image_slider_title'][ $i ]);
			}
			if ( !empty( $input[ 'featured_image_slider_content' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_content'][ $i ] = wp_kses_stripslashes($input[ 'featured_image_slider_content'][ $i ]);
			}
		}
	}
	//Featured Catgory Slider
	if ( isset( $input['slider_category'] ) ) {
		$input_validated[ 'slider_category' ] = $input[ 'slider_category' ];
	}

    // data validation Content Options

    // data validation for Content Type
    if( isset( $input[ 'featured_content_type' ] ) ) {
        $input_validated[ 'featured_content_type' ] = $input[ 'featured_content_type' ];
    }
    if( isset( $input[ 'featured_content_headline' ] ) ) {
        $input_validated[ 'featured_content_headline' ] = $input[ 'featured_content_headline' ];
    }
    if( isset( $input[ 'featured_content_subheadline' ] ) ) {
        $input_validated[ 'featured_content_subheadline' ] = $input[ 'featured_content_subheadline' ];
    }
    if( isset( $input[ 'featured_content_layout' ] ) ) {
        $input_validated[ 'featured_content_layout' ] = $input[ 'featured_content_layout' ];
    }
    if( isset( $input[ 'featured_content_show' ] ) ) {
        $input_validated[ 'featured_content_show' ] = $input[ 'featured_content_show' ];
    }
    // data validation for Enable Content
    if( isset( $input[ 'featured_content_option' ] ) ) {
        $input_validated[ 'featured_content_option' ] = $input[ 'featured_content_option' ];
    }
    // data validation for number of content
    if ( isset( $input[ 'featured_content_number' ] ) ) {
        $input_validated[ 'featured_content_number' ] = absint( $input[ 'featured_content_number' ] ) ? $input [ 'featured_content_number' ] : 3;
    }

    // data validation for featured content position
    if ( isset( $input[ 'featured_content_position' ] ) ) {
        $input_validated[ 'featured_content_position' ] = $input[ 'featured_content_position' ];
    }

    // data validation for Featured Post and Page Content
    if ( isset( $input[ 'featured_content_page' ] ) ) {
        $input_validated[ 'featured_content_page' ] = array();
    }
    if ( isset( $input[ 'featured_content_number' ] ) )  {
        for ( $i = 1; $i <= $input [ 'featured_content_number' ]; $i++ ) {
            if ( !empty( $input[ 'featured_content_page' ][ $i ] ) && intval( $input[ 'featured_content_page' ][ $i ] ) ) {
                $input_validated[ 'featured_content_page' ][ $i ] = absint($input[ 'featured_content_page' ][ $i ] );
            }
        }
    }

	// data validation for Social Icons
	if ( isset( $input['disable_footer_social'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_footer_social' ] = $input[ 'disable_footer_social' ];
	}
	if( isset( $input[ 'social_facebook' ] ) ) {
		$input_validated[ 'social_facebook' ] = esc_url_raw( $input[ 'social_facebook' ] );
	}
	if( isset( $input[ 'social_twitter' ] ) ) {
		$input_validated[ 'social_twitter' ] = esc_url_raw( $input[ 'social_twitter' ] );
	}
	if( isset( $input[ 'social_googleplus' ] ) ) {
		$input_validated[ 'social_googleplus' ] = esc_url_raw( $input[ 'social_googleplus' ] );
	}
	if( isset( $input[ 'social_pinterest' ] ) ) {
		$input_validated[ 'social_pinterest' ] = esc_url_raw( $input[ 'social_pinterest' ] );
	}
	if( isset( $input[ 'social_youtube' ] ) ) {
		$input_validated[ 'social_youtube' ] = esc_url_raw( $input[ 'social_youtube' ] );
	}
	if( isset( $input[ 'social_vimeo' ] ) ) {
		$input_validated[ 'social_vimeo' ] = esc_url_raw( $input[ 'social_vimeo' ] );
	}
	if( isset( $input[ 'social_linkedin' ] ) ) {
		$input_validated[ 'social_linkedin' ] = esc_url_raw( $input[ 'social_linkedin' ] );
	}
	if( isset( $input[ 'social_aim' ] ) ) {
		$input_validated[ 'social_aim' ] = esc_url_raw( $input[ 'social_aim' ] );
	}
	if( isset( $input[ 'social_myspace' ] ) ) {
		$input_validated[ 'social_myspace' ] = esc_url_raw( $input[ 'social_myspace' ] );
	}
	if( isset( $input[ 'social_flickr' ] ) ) {
		$input_validated[ 'social_flickr' ] = esc_url_raw( $input[ 'social_flickr' ] );
	}
	if( isset( $input[ 'social_tumblr' ] ) ) {
		$input_validated[ 'social_tumblr' ] = esc_url_raw( $input[ 'social_tumblr' ] );
	}
	if( isset( $input[ 'social_deviantart' ] ) ) {
		$input_validated[ 'social_deviantart' ] = esc_url_raw( $input[ 'social_deviantart' ] );
	}
	if( isset( $input[ 'social_dribbble' ] ) ) {
		$input_validated[ 'social_dribbble' ] = esc_url_raw( $input[ 'social_dribbble' ] );
	}
	if( isset( $input[ 'social_wordpress' ] ) ) {
		$input_validated[ 'social_wordpress' ] = esc_url_raw( $input[ 'social_wordpress' ] );
	}
	if( isset( $input[ 'social_rss' ] ) ) {
		$input_validated[ 'social_rss' ] = esc_url_raw( $input[ 'social_rss' ] );
	}
	if( isset( $input[ 'social_slideshare' ] ) ) {
		$input_validated[ 'social_slideshare' ] = esc_url_raw( $input[ 'social_slideshare' ] );
	}
	if( isset( $input[ 'social_instagram' ] ) ) {
		$input_validated[ 'social_instagram' ] = esc_url_raw( $input[ 'social_instagram' ] );
	}
	if( isset( $input[ 'social_skype' ] ) ) {
		$input_validated[ 'social_skype' ] = sanitize_text_field( $input[ 'social_skype' ] );
	}
	if( isset( $input[ 'social_soundcloud' ] ) ) {
		$input_validated[ 'social_soundcloud' ] = esc_url_raw( $input[ 'social_soundcloud' ] );
	}
	if( isset( $input[ 'social_email' ] ) &&  isset( $input[ 'social_email' ] )  ) {
		$input_validated[ 'social_email' ] = sanitize_email( $input[ 'social_email' ] );
	}
	if( isset( $input[ 'social_contact' ] ) ) {
		$input_validated[ 'social_contact' ] = esc_url_raw( $input[ 'social_contact' ] );
	}
	if( isset( $input[ 'social_xing' ] ) ) {
		$input_validated[ 'social_xing' ] = esc_url_raw( $input[ 'social_xing' ] );
	}
    if( isset( $input[ 'social_meetup' ] ) ) {
        $input_validated[ 'social_meetup' ] = esc_url_raw( $input[ 'social_meetup' ] );
    }
    if( isset( $input[ 'social_goodreads' ] ) ) {
        $input_validated[ 'social_goodreads' ] = esc_url_raw( $input[ 'social_goodreads' ] );
    }
    if( isset( $input[ 'social_github' ] ) ) {
        $input_validated[ 'social_github' ] = esc_url_raw( $input[ 'social_github' ] );
    }
	if ( isset( $input['enable_specificfeeds'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'enable_specificfeeds' ] = $input[ 'enable_specificfeeds' ];
	}

	//Clearing the theme option cache
	if( function_exists( 'catchflames_themeoption_invalidate_caches' ) ) catchflames_themeoption_invalidate_caches();

	return $input_validated;
}


/*
 * Clearing the cache if any changes in Admin Theme Option
 */
function catchflames_themeoption_invalidate_caches(){
	delete_transient( 'catchflames_responsive' ); // Disable responsive layout
	delete_transient( 'catchflames_inline_css' ); // Custom Inline CSS and color options
	delete_transient( 'catchflames_default_sliders' ); // featured demo slider
	delete_transient( 'catchflames_post_sliders' ); // featured post slider
	delete_transient( 'catchflames_page_sliders' ); // featured page slider
	delete_transient( 'catchflames_category_sliders' ); // featured category slider
	delete_transient( 'catchflames_image_sliders' ); // featured image slider
	delete_transient( 'catchflames_social_networks' );  // Social links on header
	delete_transient( 'catchflames_social_search' );  // Social links with search  on header
	delete_transient( 'catchflames_footer_content' ); // Footer content
	delete_transient( 'catchflames_logo'); // Header logo
    delete_transient( 'catchflames_featured_content'); // Featured Content
    delete_transient( 'catchflames_promotion_headline'); // Promotion Headline
}

/*
 * Clearing the cache if any changes in post or page
 */
function catchflames_post_invalidate_caches(){
	delete_transient( 'catchflames_post_sliders' ); // featured post slider
	delete_transient( 'catchflames_page_sliders' ); // featured page slider
	delete_transient( 'catchflames_category_sliders' ); // featured category slider
}
//Add action hook here save post
add_action( 'save_post', 'catchflames_post_invalidate_caches' );


/*
 * Clearing the cache if any changes in Custom Header
 */
function catchflames_customheader_invalidate_caches(){
	delete_transient( 'catchflames_logo'); // Header logo
}
//Add action hook here save post
add_action( 'custom_header_options', 'catchflames_customheader_invalidate_caches' );


/**
 * Function to display the current year.
 *
 * @uses date() Gets the current year.
 * @return string
 */
function catchflames_the_year() {
	return esc_attr( date_i18n( __( 'Y', 'catch-flames' ) ) );
}


/**
 * Function to display a link back to the site.
 *
 * @uses get_bloginfo() Gets the site link
 * @return string
 */
function catchflames_site_link() {
	return '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" ><span>' . get_bloginfo( 'name', 'display' ) . '</span></a>';
}


/**
 * Function to display a link to WordPress.org.
 *
 * @return string
 */
function catchflames_theme_name() {
    return '<span class="theme-name">' . __( 'Theme: Catch Flames by ', 'catch-flames' ) . '</span>';
}


/**
 * Function to display a link to Theme Link.
 *
 * @return string
 */
function catchflames_theme_author() {

    return '<span class="theme-author"><a href="' . esc_url( 'https://catchthemes.com/' ) . '" target="_blank" title="' . esc_attr__( 'Catch Themes', 'catch-flames' ) . '">' . __( 'Catch Themes', 'catch-flames' ) . '</a></span>';

}


/**
 * Function to display Catch Flames Assets
 *
 * @return string
 */
function catchflames_assets(){
    $catchflames_content = '<div class="copyright">'. esc_attr__( 'Copyright', 'catch-flames' ) . ' &copy; '. catchflames_the_year() . ' ' . catchflames_site_link() . ' ' . esc_attr__( 'All Rights Reserved.', 'catch-flames' ) . ' ' . get_the_privacy_policy_link() . '</div><div class="powered">'. catchflames_theme_name() . catchflames_theme_author() . '</div>';
    return $catchflames_content;
}
